summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/ChangeLog4
-rw-r--r--src/ChangeLog.44
-rw-r--r--src/ChangeLog.92
-rw-r--r--src/alloc.c2
-rw-r--r--src/image.c6
-rw-r--r--src/regex.c2
6 files changed, 12 insertions, 8 deletions
diff --git a/src/ChangeLog b/src/ChangeLog
index 860c019eb0..e8bd3ac3e1 100644
--- a/src/ChangeLog
+++ b/src/ChangeLog
@@ -1,3 +1,7 @@
+2011-11-15 Juanma Barranquero <lekktu@gmail.com>
+
+ * image.c (imagemagick_load_image): Fix typo.
+
2011-11-14 Eli Zaretskii <eliz@gnu.org>
* xdisp.c (display_line): Move the call to
diff --git a/src/ChangeLog.4 b/src/ChangeLog.4
index dc8fe23a22..208d9c2cdb 100644
--- a/src/ChangeLog.4
+++ b/src/ChangeLog.4
@@ -811,7 +811,7 @@
1994-04-28 Michael D. Ernst (mernst@monozygote.research.microsoft.com)
- * fileio.c (inhibit-file-name-handers): Correct documentation.
+ * fileio.c (inhibit-file-name-handlers): Correct documentation.
1994-04-28 Karl Heuer (kwzh@hal.gnu.ai.mit.edu)
@@ -1885,7 +1885,7 @@
1994-03-22 Frederic Pierresteguy (fp@mole.gnu.ai.mit.edu)
* widget.c (set_frame_size): Put #if 0 around a lot of useless code.
- Compute explicitely the geometry of the toplevel widget.
+ Compute explicitly the geometry of the toplevel widget.
Call XtSetValues not XtVaSetValues.
1994-03-22 Richard Stallman (rms@mole.gnu.ai.mit.edu)
diff --git a/src/ChangeLog.9 b/src/ChangeLog.9
index 1a4abfab61..9e7bd24f79 100644
--- a/src/ChangeLog.9
+++ b/src/ChangeLog.9
@@ -8409,7 +8409,7 @@
(encode_coding_iso2022): New local variable safe_chars. Check
unsafe chars.
(setup_coding_system): Delete the code to initialize
- coding->safe_charses.
+ coding->safe_charsets.
(intersection, find_safe_codings): New functions.
(Ffind_coding_systems_region_internal): New function.
(syms_of_coding): Defsubr it. Initialize Qsafe_chars,
diff --git a/src/alloc.c b/src/alloc.c
index 1d274e2111..5d04bd7787 100644
--- a/src/alloc.c
+++ b/src/alloc.c
@@ -1412,7 +1412,7 @@ uninterrupt_malloc (void)
#ifdef DOUG_LEA_MALLOC
pthread_mutexattr_t attr;
- /* GLIBC has a faster way to do this, but lets keep it portable.
+ /* GLIBC has a faster way to do this, but let's keep it portable.
This is according to the Single UNIX Specification. */
pthread_mutexattr_init (&attr);
pthread_mutexattr_settype (&attr, PTHREAD_MUTEX_RECURSIVE);
diff --git a/src/regex.c b/src/regex.c
index ccbad58abb..b7699378f5 100644
--- a/src/regex.c
+++ b/src/regex.c
@@ -637,7 +637,7 @@ typedef enum
on_failure_jump_nastyloop,
/* A smart `on_failure_jump' used for greedy * and + operators.
- It analyses the loop before which it is put and if the
+ It analyzes the loop before which it is put and if the
loop does not require backtracking, it changes itself to
`on_failure_keep_string_jump' and short-circuits the loop,
else it just defaults to changing itself into `on_failure_jump'.
diff --git a/src/image.c b/src/image.c
index 8b64bdf20b..e80f2b7210 100644
--- a/src/image.c
+++ b/src/image.c
@@ -7552,7 +7552,7 @@ imagemagick_image_p (Lisp_Object object)
}
/* The GIF library also defines DrawRectangle, but its never used in Emacs.
- Therefore rename the function so it doesnt collide with ImageMagick. */
+ Therefore rename the function so it doesn't collide with ImageMagick. */
#define DrawRectangle DrawRectangleGif
#include <wand/MagickWand.h>
@@ -7841,7 +7841,7 @@ imagemagick_load_image (struct frame *f, struct image *img,
}
/* Oddly, the below code doesnt seem to work:*/
/* switch(ximg->bitmap_unit){ */
/* case 8: */
/* pixelwidth=CharPixel; */
@@ -7870,7 +7870,7 @@ imagemagick_load_image (struct frame *f, struct image *img,
/*&(img->pixmap));*/
ximg->data);
#else
- image_error ("You dont have MagickExportImagePixels, upgrade ImageMagick!",
+ image_error ("You don't have MagickExportImagePixels, upgrade ImageMagick!",
Qnil, Qnil);
#endif
}
@@ -7841,7 +7841,7 @@ imagemagick_load_image (struct frame *f, struct image *img,
}
- /* Oddly, the below code doesnt seem to work:*/
+ /* Oddly, the below code doesn't seem to work:*/
/* switch(ximg->bitmap_unit){ */
/* case 8: */